/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.planning.wizard;

import org.openide.WizardDescriptor;

/**
 * Wrapper interface to indicate that a WizardAction is a planning wizard  action.
 * 
 * Is used by PlanningWizard.
 * 
 * The way to use is as follows:
 * 
 * - Create a wizard via standard way in Netbeans following wizard new wizard.
 * - Let the action which activates the wizard and instantiates the panels extend this interface
 * - Let that same class be service provider of this class by adding @ServiceProvider(service=PlanningWizardAction.class)
 * - make getPanels() method public
 * 
 * By doing so your newly created wizard should appear in the drop down box in the first screen of planning wizard 
 * 
 * @author Merijn Zengers
 */
public interface PlanningWizardAction{
   
    /**
     * Gets the name of the wizard. Shown in title portion of the wizard 
     * @return String the name of the wizard
     */
    String getWizardName();
    
    /**
     * Gets all the panels for this wizard. 
     * The implementation should be the standard generated code by Netbeans wizard creator 
     * @return WizardDescriptor.Panel[] array containing all the panels for this wizard. 
     */
    WizardDescriptor.Panel[] getPanels();
    
    /**
     * This method is called when the finish button in the wizard is called.
     * If information from the input in the wizard must be saved put the code in this method.
     * @param wizardDescriptor the WizardDescriptor for this wizard.
     */
    void save(WizardDescriptor wizardDescriptor);
    void clear(WizardDescriptor wizardDescriptor);
}
